import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import React, { forwardRef, createElement, useState, useRef } from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import IconButton from '@material-ui/core/IconButton';
import InputAdornment from '@material-ui/core/InputAdornment';
import TextField from '@material-ui/core/TextField';
import withStyles from '@material-ui/core/styles/withStyles';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import makeStyles from '@material-ui/core/styles/makeStyles';
import Accordion from '@material-ui/core/Accordion';
import AccordionDetails from '@material-ui/core/AccordionDetails';
import AccordionSummary from '@material-ui/core/AccordionSummary';
import Icon from '@material-ui/core/Icon';
import Paper from '@material-ui/core/Paper';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import format from 'date-fns/format';
import { ScrollSync, AutoSizer, Grid } from 'react-virtualized';
import Draggable from 'react-draggable';
import Checkbox from '@material-ui/core/Checkbox';
import CircularProgress from '@material-ui/core/CircularProgress';
import MenuItem from '@material-ui/core/MenuItem';
import Select from '@material-ui/core/Select';
import TableSortLabel from '@material-ui/core/TableSortLabel';
import Tooltip from '@material-ui/core/Tooltip';

var styles = {
  root: {}
};
var ActionField = /*#__PURE__*/forwardRef(function ActionField(props, ref) {
  var _props$autoComplete = props.autoComplete,
      autoComplete = _props$autoComplete === void 0 ? 'off' : _props$autoComplete,
      _props$autoFocus = props.autoFocus,
      autoFocus = _props$autoFocus === void 0 ? false : _props$autoFocus,
      classes = props.classes,
      className = props.className,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$error = props.error,
      error = _props$error === void 0 ? false : _props$error,
      _props$fullWidth = props.fullWidth,
      fullWidth = _props$fullWidth === void 0 ? true : _props$fullWidth,
      helperText = props.helperText,
      _props$hiddenAction = props.hiddenAction,
      hiddenAction = _props$hiddenAction === void 0 ? false : _props$hiddenAction,
      _props$iconActionCls = props.iconActionCls,
      iconActionCls = _props$iconActionCls === void 0 ? 'fas fa-external-link-alt' : _props$iconActionCls,
      label = props.label,
      placeholder = props.placeholder,
      _props$readOnly = props.readOnly,
      readOnly = _props$readOnly === void 0 ? true : _props$readOnly,
      value = props.value,
      _props$variant = props.variant,
      variant = _props$variant === void 0 ? 'standard' : _props$variant,
      onHandleAction = props.onHandleAction,
      onKeyPress = props.onKeyPress,
      other = _objectWithoutProperties(props, ["autoComplete", "autoFocus", "classes", "className", "disabled", "error", "fullWidth", "helperText", "hiddenAction", "iconActionCls", "label", "placeholder", "readOnly", "value", "variant", "onHandleAction", "onKeyPress"]);

  var handleKeyPress = function handleKeyPress(event) {
    if (typeof onKeyPress === "function") {
      onKeyPress(event);
    }

    if (event.key === 'Enter') {
      onHandleAction(event);
    }
  };

  return /*#__PURE__*/createElement(TextField, _extends({
    autoComplete: autoComplete,
    autoFocus: autoFocus,
    className: clsx(classes.root, className),
    disabled: disabled,
    error: error,
    fullWidth: fullWidth,
    helperText: helperText,
    label: label,
    placeholder: placeholder,
    value: value,
    variant: variant,
    onKeyPress: handleKeyPress,
    InputProps: {
      endAdornment: !hiddenAction && /*#__PURE__*/createElement(InputAdornment, {
        position: "end"
      }, /*#__PURE__*/createElement(IconButton, {
        disabled: disabled,
        className: iconActionCls,
        tabIndex: -1,
        style: {
          fontSize: '0.8125rem'
        },
        onClick: onHandleAction
      })),
      readOnly: readOnly
    },
    ref: ref
  }, other));
});
process.env.NODE_ENV !== "production" ? ActionField.propTypes = {
  autoComplete: PropTypes.string,
  autoFocus: PropTypes.bool,
  classes: PropTypes.object,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.bool,
  fullWidth: PropTypes.bool,
  helperText: PropTypes.node,
  label: PropTypes.node,
  onHandleAction: PropTypes.func,
  onKeyPress: PropTypes.func,
  placeholder: PropTypes.string,
  readOnly: PropTypes.bool,
  value: PropTypes.any,

  /**
   * The variant to use.
   * @default 'standard'
   */
  variant: PropTypes.oneOf(['filled', 'outlined', 'standard'])
} : void 0;
var ActionField$1 = withStyles(styles)(ActionField);

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var useStyles = makeStyles(function () {
  return {
    root: {
      display: 'flex',
      flex: '1 1 auto',
      flexDirection: 'column',
      padding: '0 .5rem .125rem',
      overflowY: 'auto',
      '@media (min-width: 701px)': {
        padding: '0 .75rem .375rem'
      },
      '@media (min-width: 1401px)': {
        padding: '0 1rem .625rem'
      }
    }
  };
});

var Body = function Body(props) {
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("div", {
    className: classes.root,
    style: _objectSpread({}, props.style)
  }, props.children);
};

process.env.NODE_ENV !== "production" ? Body.propTypes = {} : void 0;

var useStyles$1 = makeStyles(function () {
  return {
    icon: {
      color: '#3c4858',
      fontSize: '0.8125rem',
      paddingRight: 6
    },
    iconCollapse: {
      color: '#3c4858',
      fontSize: '1.25rem'
    },
    title: {
      display: 'flex',
      fontSize: '0.8125rem',
      minHeight: '1.75rem',
      padding: '0 0.75rem 0 0.75rem'
    },
    titleContent: {
      alignItems: 'center',
      display: 'flex'
    }
  };
});

var FieldSet = function FieldSet(props) {
  var classes = useStyles$1();
  var className = props.className,
      defaultExpanded = props.defaultExpanded,
      expandable = props.expandable,
      iconCls = props.iconCls,
      title = props.title;

  if (expandable) {
    return /*#__PURE__*/React.createElement(Accordion, {
      className: className,
      defaultExpanded: defaultExpanded
    }, /*#__PURE__*/React.createElement(AccordionSummary, {
      className: classes.title,
      expandIcon: /*#__PURE__*/React.createElement(Icon, {
        className: clsx("fas fa-angle-down", classes.iconCollapse)
      })
    }, /*#__PURE__*/React.createElement("div", {
      className: classes.titleContent
    }, /*#__PURE__*/React.createElement(Icon, {
      className: clsx(iconCls, classes.icon)
    }), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }, title))), /*#__PURE__*/React.createElement(AccordionDetails, null, props.children));
  }

  return /*#__PURE__*/React.createElement(Paper, {
    className: className
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.title
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.titleContent
  }, /*#__PURE__*/React.createElement(Icon, {
    className: clsx(iconCls, classes.icon)
  }), /*#__PURE__*/React.createElement("div", null, title))), props.children);
};

process.env.NODE_ENV !== "production" ? FieldSet.propTypes = {
  className: PropTypes.string,
  defaultExpanded: PropTypes.bool,
  expandable: PropTypes.bool,
  iconCls: PropTypes.string,
  title: PropTypes.string
} : void 0;

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$1(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var useStyles$2 = makeStyles(function () {
  return {
    root: {
      alignItems: 'center',
      display: 'flex',
      flex: '0 0 auto',
      justifyContent: 'flex-end',
      padding: '0.375rem 0.5rem',
      '@media (min-width: 701px)': {
        padding: '0.375rem 0.75rem'
      },
      '@media (min-width: 1401px)': {
        padding: '0.375rem 1rem'
      },
      '& > *': {
        marginLeft: '.5rem'
      }
    }
  };
});

var Footer = function Footer(props) {
  var classes = useStyles$2();
  return /*#__PURE__*/React.createElement("div", {
    className: classes.root,
    style: _objectSpread$1({}, props.style)
  }, props.children);
};

process.env.NODE_ENV !== "production" ? Footer.propTypes = {} : void 0;

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$2(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var Page = function Page(props) {
  return /*#__PURE__*/React.createElement("div", {
    style: _objectSpread$2({
      display: 'flex',
      flex: '1 1 auto',
      flexDirection: 'column',
      overflowY: 'auto'
    }, props.style)
  }, props.children);
};

process.env.NODE_ENV !== "production" ? Page.propTypes = {} : void 0;

function ownKeys$3(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$3(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$3(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$3(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var useStyles$3 = makeStyles(function (theme) {
  return {
    actionButton: {
      padding: 0
    },
    actionIcon: {
      fontSize: '.875rem',
      width: 'auto'
    },
    actionIconSelected: {
      color: theme.palette.primary.contrastText
    },
    center: {
      flexGrow: 1,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    },
    cell: {
      borderBottom: '1px solid rgba(224, 224, 224, 1)',
      borderRight: '1px solid rgba(224, 224, 224, 1)',
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis',
      overflow: 'hidden',
      boxSizing: 'border-box',
      padding: '6px 5px 5px 6px',
      userSelect: 'none'
    },
    cellAction: {
      borderBottom: '1px solid rgba(224, 224, 224, 1)',
      borderRight: '1px solid rgba(224, 224, 224, 1)',
      boxSizing: 'border-box',
      overflow: 'hidden',
      padding: '6px 5px 5px 6px',
      textAlign: 'center',
      userSelect: 'none'
    },
    cellNumber: {
      textAlign: 'right'
    },
    cellRowNumber: {
      backgroundImage: '-webkit-linear-gradient(top, #fff, #fff 30%, #fff 65%, #f0f0f0)',
      textAlign: 'center'
    },
    checkBox: {
      color: theme.palette.primary.contrastText
    },
    dragHandle: {
      flex: '0 0 16px',
      zIndex: 2,
      cursor: 'col-resize',
      color: '#0085ff',
      '&:hover': {
        backgroundColor: 'rgba(0, 0, 0, 0.1)'
      }
    },
    dragHandleActive: {
      color: '#0b6fcc',
      zIndex: 3,
      '&:hover': {
        color: '#0b6fcc',
        zIndex: 3
      }
    },
    dragHandleIcon: {
      flex: '0 0 3px',
      display: 'flex',
      flexDirection: 'column',
      justifyContent: 'center',
      alignItems: 'center'
    },
    header: {
      backgroundImage: '-webkit-linear-gradient(top, #fff, #fff 30%, #fff 65%, #f0f0f0)',
      borderTop: '1px solid rgba(224, 224, 224, 1)',
      borderBottom: '1px solid rgba(224, 224, 224, 1)',
      overflow: 'hidden !important'
    },
    headerCell: {
      borderBottom: 'none',
      borderRight: '1px solid rgba(224, 224, 224, 1)',
      boxSizing: 'border-box',
      padding: '6px 0 6px 6px',
      userSelect: 'none',
      '&:hover': {
        backgroundImage: "-webkit-linear-gradient(top, #fff, #fff 30%, ".concat(theme.palette.primary.light, " 65%, ").concat(theme.palette.primary.light, ")")
      },
      display: 'flex'
    },
    headerContent: {
      flex: 'auto',
      overflow: 'hidden',
      textOverflow: 'ellipsis',
      whiteSpace: 'nowrap'
    },
    icon: {
      fontSize: '0.75rem'
    },
    pagination: {
      borderTop: '1px solid rgba(224, 224, 224, 1)'
    },
    paginationActions: {
      flexShrink: 0,
      marginLeft: '1.25rem',
      marginRight: '0.5rem'
    },
    paginationCaption: {
      flexShrink: 0
    },
    paginationSelect: {
      flexShrink: 0,
      marginLeft: '0.5rem',
      marginRight: '1.25rem'
    },
    rowHover: {
      backgroundColor: theme.palette.primary.light
    },
    rowSelected: {
      backgroundColor: theme.palette.primary.main,
      color: theme.palette.primary.contrastText
    },
    sortIcon: {
      height: 14,
      width: 14
    },
    spacer: {
      flex: '1 1 100%'
    },
    textNoData: {
      color: "gray",
      fontSize: '0.75rem',
      padding: '0.625rem'
    },
    toolbar: {
      alignItems: 'center',
      display: 'flex',
      fontFamily: 'inherit',
      fontSize: '0.75rem',
      minHeight: '2.25rem',
      position: 'relative'
    }
  };
});

var Table = function Table(props) {
  var classes = useStyles$3();

  var _useState = useState(-1),
      _useState2 = _slicedToArray(_useState, 2),
      rowHoverIndex = _useState2[0],
      setRowHoverIndex = _useState2[1];

  var headerEl = useRef(null);
  var bodyEl = useRef(null);
  var actions = props.actions,
      columns = props.columns,
      count = props.count,
      enableColumnResize = props.enableColumnResize,
      loading = props.loading,
      multiSelect = props.multiSelect,
      page = props.page,
      paginate = props.paginate,
      rowCount = props.rowCount,
      rowHeight = props.rowHeight,
      rowNumber = props.rowNumber,
      rowsPerPage = props.rowsPerPage,
      selected = props.selected,
      sortableColumns = props.sortableColumns,
      sortBy = props.sortBy,
      sortDirection = props.sortDirection;
  var editor = props.editor,
      onChangePage = props.onChangePage,
      onChangeRowsPerPage = props.onChangeRowsPerPage,
      onRowClick = props.onRowClick,
      onRowDoubleClick = props.onRowDoubleClick,
      onSort = props.onSort,
      onUpdateColumn = props.onUpdateColumn,
      rowGetter = props.rowGetter;

  var handleSelectAllClick = function handleSelectAllClick(event) {
    if (event.target.checked) {
      var newSelecteds = [];

      for (var index = 0; index < rowCount; index++) {
        newSelecteds.push(rowGetter(index));
      }

      onRowClick(newSelecteds);
      return;
    }

    onRowClick([]);
  };

  var handleSelectedRow = function handleSelectedRow(item) {
    var selectedIndex = selected.indexOf(item);

    if (multiSelect) {
      if (selectedIndex === -1) {
        onRowClick([].concat(_toConsumableArray(selected), [item]));
      } else {
        onRowClick(selected.filter(function (i) {
          return i !== item;
        }));
      }
    } else {
      if (selectedIndex === -1) {
        onRowClick([item]);
      }
    }
  };

  var resizeColumn = function resizeColumn(_ref) {
    var column = _ref.column,
        deltaX = _ref.deltaX;

    if (column.width + deltaX <= 25) {
      return;
    }

    column.width += deltaX;
    onUpdateColumn(column);
    headerEl.current.recomputeGridSize();

    if (bodyEl.current) {
      bodyEl.current.recomputeGridSize();
    }
  };

  var renderHeaderCell = function renderHeaderCell(_ref2) {
    var columnIndex = _ref2.columnIndex,
        key = _ref2.key,
        rowIndex = _ref2.rowIndex,
        style = _ref2.style;

    if (rowNumber && columnIndex === 0) {
      return /*#__PURE__*/React.createElement("div", {
        className: clsx(classes.headerCell, classes.cellRowNumber),
        key: key,
        style: style
      });
    }

    if (!rowNumber && multiSelect && columnIndex === 0 || rowNumber && multiSelect && columnIndex === 1) {
      return /*#__PURE__*/React.createElement("div", {
        className: classes.headerCell,
        key: key,
        style: style
      }, /*#__PURE__*/React.createElement(Checkbox, {
        indeterminate: selected.length > 0 && selected.length < rowCount,
        checked: selected.length === rowCount,
        color: "default",
        onChange: handleSelectAllClick,
        style: {
          padding: 0
        }
      }));
    }

    if ((rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length > columnIndex) {
      return /*#__PURE__*/React.createElement("div", {
        className: clsx(classes.headerCell, classes.cellRowNumber),
        key: key,
        style: style
      });
    }

    columnIndex = columnIndex - (rowNumber ? 1 : 0) - (multiSelect ? 1 : 0) - actions.length;
    return /*#__PURE__*/React.createElement("div", {
      className: classes.headerCell,
      key: key,
      style: style
    }, sortableColumns && /*#__PURE__*/React.createElement(TableSortLabel, {
      className: classes.headerContent,
      classes: {
        icon: classes.sortIcon
      },
      active: sortBy === columns[columnIndex].dataKey,
      direction: sortDirection,
      onClick: function onClick() {
        return onSort(columns[columnIndex].dataKey);
      }
    }, columns[columnIndex].label), !sortableColumns && /*#__PURE__*/React.createElement("div", {
      className: classes.headerContent
    }, columns[columnIndex].label), enableColumnResize && /*#__PURE__*/React.createElement(Draggable, {
      axis: "x",
      defaultClassName: classes.dragHandle,
      defaultClassNameDragging: classes.dragHandleActive,
      onDrag: function onDrag(event, _ref3) {
        var deltaX = _ref3.deltaX;
        return resizeColumn({
          column: _objectSpread$3({}, columns[columnIndex]),
          deltaX: deltaX
        });
      },
      position: {
        x: 0
      },
      zIndex: 999
    }, /*#__PURE__*/React.createElement("span", {
      className: classes.dragHandleIcon
    })));
  };

  var renderRowCell = function renderRowCell(_ref4) {
    var columnIndex = _ref4.columnIndex,
        key = _ref4.key,
        rowIndex = _ref4.rowIndex,
        style = _ref4.style;

    if (rowNumber && columnIndex === 0) {
      return /*#__PURE__*/React.createElement("div", {
        className: clsx(classes.cell, classes.cellRowNumber),
        key: key,
        style: style,
        onClick: function onClick() {
          return handleSelectedRow(rowGetter(rowIndex));
        }
      }, paginate ? page * rowsPerPage + rowIndex + 1 : rowIndex + 1);
    }

    if (!rowNumber && multiSelect && columnIndex === 0 || rowNumber && multiSelect && columnIndex === 1) {
      return /*#__PURE__*/React.createElement("div", {
        className: clsx(classes.cell, selected.indexOf(rowGetter(rowIndex)) !== -1 && classes.rowSelected, rowIndex === rowHoverIndex && classes.rowHover),
        key: key,
        style: style,
        onClick: function onClick() {
          return handleSelectedRow(rowGetter(rowIndex));
        },
        onMouseEnter: function onMouseEnter() {
          return setRowHoverIndex(rowIndex);
        },
        onMouseLeave: function onMouseLeave() {
          return setRowHoverIndex(-1);
        }
      }, /*#__PURE__*/React.createElement(Checkbox, {
        className: selected.indexOf(rowGetter(rowIndex)) !== -1 ? classes.checkBox : null,
        checked: selected.indexOf(rowGetter(rowIndex)) !== -1,
        color: "default",
        style: {
          padding: 0
        }
      }));
    }

    if ((rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length > columnIndex) {
      var i = columnIndex - (rowNumber ? 1 : 0) - (multiSelect ? 1 : 0);
      return /*#__PURE__*/React.createElement("div", {
        className: clsx(classes.cellAction, selected.indexOf(rowGetter(rowIndex)) !== -1 && classes.rowSelected, rowIndex === rowHoverIndex && classes.rowHover),
        key: key,
        style: style,
        onMouseEnter: function onMouseEnter() {
          return setRowHoverIndex(rowIndex);
        },
        onMouseLeave: function onMouseLeave() {
          return setRowHoverIndex(-1);
        }
      }, actions[i].tooltip && /*#__PURE__*/React.createElement(Tooltip, {
        title: actions[i].tooltip,
        arrow: true
      }, /*#__PURE__*/React.createElement(IconButton, {
        className: classes.actionButton,
        onClick: function onClick() {
          return actions[i].onClick(rowGetter(rowIndex));
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        className: clsx(classes.actionIcon, actions[i].iconCls, selected.indexOf(rowGetter(rowIndex)) !== -1 && classes.actionIconSelected)
      }))), !actions[i].tooltip && /*#__PURE__*/React.createElement(IconButton, {
        className: classes.actionButton,
        onClick: function onClick() {
          return actions[i].onClick(rowGetter(rowIndex));
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        className: clsx(classes.actionIcon, actions[i].iconCls, selected.indexOf(rowGetter(rowIndex)) !== -1 && classes.actionIconSelected)
      })));
    }

    columnIndex = columnIndex - (rowNumber ? 1 : 0) - (multiSelect ? 1 : 0) - actions.length;
    var type = columns[columnIndex].type;
    var value = null;

    switch (type) {
      case 'boolean':
        value = rowGetter(rowIndex)[columns[columnIndex].dataKey] ? columns[columnIndex].trueText || 'Si' : columns[columnIndex].trueText || 'No';
        break;

      case 'datetime':
        value = rowGetter(rowIndex)[columns[columnIndex].dataKey] ? format(new Date(rowGetter(rowIndex)[columns[columnIndex].dataKey]), columns[columnIndex].format || 'dd/MM/yyyy') : '';
        break;

      case 'number':
        value = new Intl.NumberFormat('en-US', {
          minimumFractionDigits: columns[columnIndex].decimalPrecision || 2,
          maximumFractionDigits: columns[columnIndex].decimalPrecision || 2
        }).format(rowGetter(rowIndex)[columns[columnIndex].dataKey]);
        break;

      default:
        value = rowGetter(rowIndex)[columns[columnIndex].dataKey];
        break;
    }

    return /*#__PURE__*/React.createElement("div", {
      className: clsx(classes.cell, selected.indexOf(rowGetter(rowIndex)) !== -1 && classes.rowSelected, rowIndex === rowHoverIndex && classes.rowHover, type === 'number' && classes.cellNumber),
      key: key,
      style: style,
      onClick: function onClick() {
        return handleSelectedRow(rowGetter(rowIndex));
      },
      onDoubleClick: function onDoubleClick() {
        return onRowDoubleClick(rowGetter(rowIndex));
      },
      onMouseEnter: function onMouseEnter() {
        return setRowHoverIndex(rowIndex);
      },
      onMouseLeave: function onMouseLeave() {
        return setRowHoverIndex(-1);
      }
    }, editor ? editor(columnIndex, rowGetter(rowIndex), columns[columnIndex].dataKey) || value : value);
  };

  return /*#__PURE__*/React.createElement(ScrollSync, null, function (_ref5) {
    var onScroll = _ref5.onScroll,
        scrollLeft = _ref5.scrollLeft;
    return /*#__PURE__*/React.createElement(AutoSizer, null, function (_ref6) {
      var height = _ref6.height,
          width = _ref6.width;
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Grid, {
        cellRenderer: renderHeaderCell,
        className: classes.header,
        columnCount: columns.length + (rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length,
        columnWidth: function columnWidth(_ref7) {
          var index = _ref7.index;

          if (rowNumber && index === 0) {
            return 35;
          }

          if (!rowNumber && multiSelect && index === 0) {
            return 32;
          }

          if (rowNumber && multiSelect && index === 1) {
            return 32;
          }

          if ((rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length > index) {
            return 32;
          }

          return columns[index - (rowNumber ? 1 : 0) - (multiSelect ? 1 : 0) - actions.length].width;
        },
        height: 26,
        ref: headerEl,
        rowCount: 1,
        rowHeight: rowHeight,
        scrollLeft: scrollLeft,
        style: {
          outline: 'none',
          fontSize: '0.6875rem'
        },
        width: width
      }), rowCount > 0 && !loading && /*#__PURE__*/React.createElement(Grid, {
        cellRenderer: renderRowCell,
        columnCount: columns.length + (rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length,
        columnWidth: function columnWidth(_ref8) {
          var index = _ref8.index;

          if (rowNumber && index === 0) {
            return 35;
          }

          if (!rowNumber && multiSelect && index === 0) {
            return 32;
          }

          if (rowNumber && multiSelect && index === 1) {
            return 32;
          }

          if ((rowNumber ? 1 : 0) + (multiSelect ? 1 : 0) + actions.length > index) {
            return 32;
          }

          return columns[index - (rowNumber ? 1 : 0) - (multiSelect ? 1 : 0) - actions.length].width;
        },
        height: height - rowHeight - (paginate ? 36 : 0),
        onScroll: onScroll,
        ref: bodyEl,
        rowCount: rowCount,
        rowHeight: rowHeight,
        style: {
          outline: 'none',
          fontSize: '0.6875rem',
          fontWeight: 400,
          lineHeight: 1.43,
          borderBottom: '1px solid rgba(224, 224, 224, 1)',
          letterSpacing: '0.01071em'
        },
        width: width
      }), (rowCount === 0 || loading) && /*#__PURE__*/React.createElement("div", {
        style: {
          height: height - 62,
          width: width
        }
      }, loading && /*#__PURE__*/React.createElement("div", {
        className: classes.center
      }, /*#__PURE__*/React.createElement(CircularProgress, {
        color: "primary"
      })), !loading && /*#__PURE__*/React.createElement("div", {
        className: classes.textNoData
      }, "No se encontraron registros")), paginate && /*#__PURE__*/React.createElement("div", {
        style: {
          height: 36,
          width: width
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: classes.pagination
      }, /*#__PURE__*/React.createElement("div", {
        className: classes.toolbar
      }, /*#__PURE__*/React.createElement("div", {
        className: classes.spacer
      }), /*#__PURE__*/React.createElement("p", {
        className: classes.paginationCaption
      }, "Filas por p\xE1gina"), /*#__PURE__*/React.createElement(Select, {
        className: classes.paginationSelect,
        onChange: onChangeRowsPerPage,
        value: rowsPerPage,
        variant: "outlined"
      }, /*#__PURE__*/React.createElement(MenuItem, {
        value: 50
      }, "50"), /*#__PURE__*/React.createElement(MenuItem, {
        value: 100
      }, "100"), /*#__PURE__*/React.createElement(MenuItem, {
        value: 200
      }, "200")), /*#__PURE__*/React.createElement("p", {
        className: classes.paginationCaption
      }, count === 0 ? 0 : page * rowsPerPage + 1, "-", count === 0 ? 0 : count > (page + 1) * rowsPerPage ? (page + 1) * rowsPerPage : count, " de ", count), /*#__PURE__*/React.createElement("div", {
        className: classes.paginationActions
      }, /*#__PURE__*/React.createElement(IconButton, {
        disabled: page === 0,
        disableRipple: true,
        onClick: function onClick() {
          return onChangePage(page - 1);
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        className: clsx("fas fa-chevron-left", classes.icon)
      })), /*#__PURE__*/React.createElement(IconButton, {
        disabled: page === parseInt(count / rowsPerPage),
        disableRipple: true,
        onClick: function onClick() {
          return onChangePage(page + 1);
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        className: clsx("fas fa-chevron-right", classes.icon)
      })))))));
    });
  });
};

Table.defaultProps = {
  actions: [],
  enableColumnResize: true,
  loading: false,
  multiSelect: false,
  paginate: false,
  rowHeight: 26,
  rowNumber: true,
  sortableColumns: true
};
process.env.NODE_ENV !== "production" ? Table.propTypes = {
  actions: PropTypes.arrayOf(PropTypes.shape({
    iconCls: PropTypes.string,
    tooltip: PropTypes.string,
    onClick: PropTypes.func
  })),
  columns: PropTypes.arrayOf(PropTypes.shape({
    dataKey: PropTypes.string.isRequired,
    decimalPrecision: PropTypes.number,
    label: PropTypes.string.isRequired,
    type: PropTypes.string,
    width: PropTypes.number
  })).isRequired,
  count: PropTypes.number,
  editor: PropTypes.func,
  enableColumnResize: PropTypes.bool,
  loading: PropTypes.bool,
  multiSelect: PropTypes.bool,
  onChangePage: PropTypes.func,
  onChangeRowsPerPage: PropTypes.func,
  onRowClick: PropTypes.func,
  onRowDoubleClick: PropTypes.func,
  onSort: PropTypes.func,
  onUpdateColumn: PropTypes.func,
  page: PropTypes.number,
  paginate: PropTypes.bool,
  rowCount: PropTypes.number.isRequired,
  rowGetter: PropTypes.func.isRequired,
  rowHeight: PropTypes.number.isRequired,
  rowNumber: PropTypes.bool,
  rowsPerPage: PropTypes.number,
  selected: PropTypes.array,
  sortableColumns: PropTypes.bool,
  sortBy: PropTypes.string,
  sortDirection: PropTypes.string
} : void 0;

export { ActionField$1 as ActionField, Body, FieldSet, Footer, Page, Table };
//# sourceMappingURL=index.es.js.map
